@@ -11,16 +11,41 @@ from .Citation import Citation
 from .Implementation import Implementation
 from ..tools import aslist
 
-from datamodelbase.record import Record
-from datamodelbase import query
-
-modelroot = 'interatomic-potential'
+from yabadaba.record import Record
+from yabadaba import load_query 
 
 class Potential(Record):
     """
     Class for representing Potential metadata records.
     """
 
+    def __init__(self, model=None, name=None, **kwargs):
+        """
+        Initializes a Record object for a given style.
+        
+        Parameters
+        ----------
+        model : str, file-like object, DataModelDict
+            The contents of the record.
+        name : str, optional
+            The unique name to assign to the record.  If model is a file
+            path, then the default record name is the file name without
+            extension.
+        
+        """
+        # Set default values
+        self.elements = None
+        self.key = None
+        self.othername = None
+        self.fictional = False
+        self.modelname = None
+        self.notes = None
+        self.recorddate = datetime.date.today()
+        self.__citations = []
+        self.__implementations = []
+
+        super().__init__(model=model, name=name, **kwargs)
+
     @property
     def style(self):
         """str: The record style"""
@@ -28,21 +53,33 @@ class Potential(Record):
 
     @property
     def xsl_filename(self):
+        """tuple: The module path and file name of the record's xsl html transformer"""
         return ('potentials.xsl', 'Potential.xsl')
 
     @property
     def xsd_filename(self):
+        """tuple: The module path and file name of the record's xsd schema"""
         return ('potentials.xsd', 'Potential.xsd')
 
     @property
     def modelroot(self):
         """str: The root element of the content"""
-        return modelroot
+        return 'interatomic-potential'
 
     def load_model(self, model, name=None):
+        """
+        Loads record contents from a given model.
 
+        Parameters
+        ----------
+        model : str or DataModelDict
+            The model contents of the record to load.
+        name : str, optional
+            The name to assign to the record.  Often inferred from other
+            attributes if not given.
+        """
         super().load_model(model, name=name)
-        potential = self.model[modelroot]
+        potential = self.model[self.modelroot]
         
         # Extract information
         self.key = potential['key']
@@ -86,7 +123,7 @@ class Potential(Record):
         if self.id != pot_id:
             try:
                 assert self.id == pot_id[:len(self.id)]
-            except:
+            except AssertionError:
                 print(f"Different ids: {self.id} != {pot_id} {self.key}")
             else:
                 self.modelname = pot_id[len(self.id):].strip('-')
@@ -99,32 +136,52 @@ class Potential(Record):
         except:
             self.name = f'potential.{self.id}'
 
+    def set_values(self, name=None, **kwargs):
+        """
+        Set multiple object attributes at the same time.
 
-    def set_values(self, name=None, elements=None, key=None,
-                   othername=None, fictional=False, modelname=None,
-                   notes=None, recorddate=None, citations=None,
-                   implementations=None):
-
-        # Build new record
-        self.elements = elements
-        self.key = key
-        self.othername = othername
-        self.fictional = fictional
-        self.modelname = modelname
-        self.notes = notes
-        self.recorddate = recorddate
+        Parameters
+        ----------
+        name : str, optional
+            The name to assign to the record.  Often inferred from other
+            attributes if not given.
+        date : str or datetime.date, optional
+            The date to assign to the record.
+        type : str, optional
+            The Action type to assign to the record.
+        potentials : list, optional
+            Potential or model contents for Potential records to associate
+            with the action.
+        comment : str, optional
+            Any additional comments to assign to the record.
+        """
         
-        self.__citations = []
-        if citations is not None:
-            for citation in aslist(citations):
+        if 'elements' in kwargs:
+            self.elements = kwargs['elements']
+        if 'key' in kwargs:
+            self.key = kwargs['key']
+        if 'othername' in kwargs:
+            self.othername = kwargs['othername']
+        if 'fictional' in kwargs:
+            self.fictional = kwargs['fictional']
+        if 'modelname' in kwargs:
+            self.modelname = kwargs['modelname']
+        if 'notes' in kwargs:
+            self.notes = kwargs['notes']
+        if 'recorddate' in kwargs:
+            self.recorddate = kwargs['recorddate']
+        
+        if 'citations' in kwargs:
+            self.__citations = []
+            for citation in aslist(kwargs['citations']):
                 if isinstance(citation, dict):
                     self.add_citation(**citation)
                 elif isinstance(citation, Citation):
                     self.citations.append(citation)
         
-        self.__implementations = []
-        if implementations is not None:
-            for implementation in aslist(implementations):
+        if 'implementations' in kwargs:
+            self.__implementations = []
+            for implementation in aslist(kwargs['implementations']):
                 if isinstance(implementation, dict):
                     self.add_implementation(**implementation)
                 elif isinstance(implementation, Implementation):
@@ -134,7 +191,10 @@ class Potential(Record):
         if name is not None:
             self.name = name
         else:
-            self.name = f'potential.{self.id}'
+            try:
+                self.name = f'potential.{self.id}'
+            except:
+                self.name = 'potential.unknown'
 
     @property
     def key(self):
@@ -199,6 +259,7 @@ class Potential(Record):
 
     @property
     def recorddate(self):
+        """datetime.date : The date associated with the record"""
         return self.__recorddate
     
     @recorddate.setter
@@ -214,14 +275,17 @@ class Potential(Record):
 
     @property
     def citations(self):
+        """list: Any associated Citation objects"""
         return self.__citations
 
     @property
     def implementations(self):
+        """list: Any associated Implementation objects"""
         return self.__implementations
 
     @property
     def elements(self):
+        """list: elements associated with the potential"""
         return self.__elements
 
     @elements.setter
@@ -233,6 +297,7 @@ class Potential(Record):
     
     @property
     def othername(self):
+        """str or None: Alternate name for what the potential models"""
         return self.__othername
     
     @othername.setter
@@ -244,6 +309,7 @@ class Potential(Record):
     
     @property
     def fictional(self):
+        """bool: Indicates if the potential is classified as fictional"""
         return self.__fictional
     
     @fictional.setter
@@ -253,6 +319,7 @@ class Potential(Record):
     
     @property
     def modelname(self):
+        """str: Extra tag for differentiating potentials when needed"""
         return self.__modelname
     
     @modelname.setter
@@ -264,6 +331,7 @@ class Potential(Record):
 
     @property
     def notes(self):
+        """str or None: Any extra notes associated with the potential"""
         return self.__notes
 
     @notes.setter
@@ -274,7 +342,11 @@ class Potential(Record):
             self.__notes = str(v)
 
     def metadata(self):
-        """Returns a flat dict representation of the object"""
+        """
+        Generates a dict of simple metadata values associated with the record.
+        Useful for quickly comparing records and for building pandas.DataFrames
+        for multiple records of the same style.
+        """
         data = {}
         
         # Copy class attributes to dict
@@ -300,11 +372,7 @@ class Potential(Record):
 
     def build_model(self):
         """
-        Returns the object info as data model content
-        
-        Returns
-        ----------
-        DataModelDict: The data model content.
+        Generates and returns model content based on the values set to object.
         """
         # Initialize model
         model = DM()
@@ -340,64 +408,197 @@ class Potential(Record):
         return model
         
     def add_citation(self, **kwargs):
+        """
+        Initializes a new Citation object and appends it to the citations list.
+        """
         self.citations.append(Citation(**kwargs))
 
     def add_implementation(self, **kwargs):
+        """
+        Initializes a new Implementation object and appends it to the implementations list.
+        """
         implementation = Implementation(**kwargs)
         for imp in self.implementations:
             if imp.id == implementation.id:
                 raise ValueError(f'Implementation with id {imp.id} already exists')
         self.implementations.append(implementation)
 
-    @staticmethod
-    def pandasfilter(dataframe, name=None, key=None, id=None,
+    @property
+    def queries(self):
+        """dict: Query objects and their associated parameter names."""
+        return {
+            'key': load_query(
+                style='str_match',
+                name='key', 
+                path=f'{self.modelroot}.key'),
+            'id': load_query(
+                style='str_match',
+                name='id',
+                path=f'{self.modelroot}.id'),
+            'notes': load_query(
+                style='str_contains',
+                name='notes',
+                path=f'{self.modelroot}.notes'),
+            'fictional': load_query(
+                style='str_match',
+                name='fictional',
+                path=f'{self.modelroot}.'),
+            'element': load_query(
+                style='list_contains',
+                name='element',
+                path=f'{self.modelroot}.element'),
+            'othername': load_query(
+                style='str_match',
+                name='othername',
+                path=f'{self.modelroot}.other-element'),
+            'modelname': load_query(
+                style='str_match',
+                name='modelname',
+                path=f'{self.modelroot}.'),
+            'year': load_query(
+                style='int_match',
+                name='year', parent='citations',
+                path=f'{self.modelroot}.description.citation.publication-date.year'),
+            'author': load_query(
+                style='str_contains',
+                name='author', parent='citations',
+                path=f'{self.modelroot}.description.citation.author.surname'),
+            'abstract': load_query(
+                style='str_contains',
+                name='abstract', parent='citations',
+                path=f'{self.modelroot}.description.citation.abstract'),
+        }
+
+    def pandasfilter(self, dataframe, name=None, key=None, id=None,
                      notes=None, fictional=None, element=None,
                      othername=None, modelname=None, year=None, author=None,
                      abstract=None):
-        matches = (
-            query.str_match.pandas(dataframe, 'name', name)
-            &query.str_match.pandas(dataframe, 'key', key)
-            &query.str_match.pandas(dataframe, 'id', id)
-            &query.str_contains.pandas(dataframe, 'notes', notes)
-            &query.str_match.pandas(dataframe, 'fictional', fictional)
-            &query.in_list.pandas(dataframe, 'elements', element)
-            &query.str_match.pandas(dataframe, 'othername', othername)
-            &query.str_match.pandas(dataframe, 'modelname', modelname)
-            &query.int_match.pandas(dataframe, 'year', year, parent='citations')
-            &query.str_contains.pandas(dataframe, 'author', author, parent='citations')
-            &query.str_contains.pandas(dataframe, 'abstract', abstract, parent='citations')
-        )
+        """
+        Filters a pandas.DataFrame based on kwargs values for the record style.
+        
+        Parameters
+        ----------
+        dataframe : pandas.DataFrame
+            A table of metadata for multiple records of the record style.
+        name : str or list
+            The record name(s) to parse by.
+        key : str or list
+            The unique potential id(s) to parse by.
+        id : str or list
+            The UUID4 potential key(s) to parse by.
+        notes : str or list
+            Terms in the notes to parse for.
+        fictional : bool or list
+            Value of fictional to parse for.
+        element : str or list
+            Element(s) to parse by.
+        othername : str or list
+            Other name(s) to parse by.
+        modelname : str or list
+            Model name(s) to parse by.
+        year : int or list
+            Publication/creation year(s) to parse by.
+        author : str or list
+            Author(s) to parse by.  Only last names guaranteed to work.
+        abstract : str or list
+            Terms in the publication abstracts to parse for.
+        
+        Returns
+        -------
+        pandas.Series, numpy.NDArray
+            Boolean map of matching values
+        """
+        matches = super().pandasfilter(dataframe, name=name, key=key, id=id,
+                                       notes=notes, fictional=fictional,
+                                       element=element, othername=othername,
+                                       modelname=modelname, year=year,
+                                       author=author, abstract=abstract)
+
         return matches
 
-    @staticmethod
-    def mongoquery(name=None, key=None, id=None,
+    def mongoquery(self, name=None, key=None, id=None,
                    notes=None, fictional=None, element=None,
                    othername=None, modelname=None, year=None, author=None,
                    abstract=None):
-        mquery = {}
-        query.str_match.mongo(mquery, f'name', name)
-
-        root = f'content.{modelroot}'
-        query.str_match.mongo(mquery, f'{root}.key', key)
-        query.str_match.mongo(mquery, f'{root}.id', id)
-        query.str_contains.mongo(mquery, f'{root}.notes', notes)
+        """
+        Builds a Mongo-style query based on kwargs values for the record style.
         
-        query.int_match.mongo(mquery, f'{root}.description.citation.publication-date.year', year)
-        query.str_contains.mongo(mquery, f'{root}.description.citation.author.surname', author)
-        query.str_contains.mongo(mquery, f'{root}.description.citation.abstract', abstract)
+        Parameters
+        ----------
+        name : str or list
+            The record name(s) to parse by.
+        key : str or list
+            The unique potential id(s) to parse by.
+        id : str or list
+            The UUID4 potential key(s) to parse by.
+        notes : str or list
+            Terms in the notes to parse for.
+        fictional : bool or list
+            Value of fictional to parse for.
+        element : str or list
+            Element(s) to parse by.
+        othername : str or list
+            Other name(s) to parse by.
+        modelname : str or list
+            Model name(s) to parse by.
+        year : int or list
+            Publication/creation year(s) to parse by.
+        author : str or list
+            Author(s) to parse by.  Only last names guaranteed to work.
+        abstract : str or list
+            Terms in the publication abstracts to parse for.
+        
+        Returns
+        -------
+        dict
+            The Mongo-style query
+        """        
+        
+        mquery = super().mongoquery(name=name, key=key, id=id,
+                                    notes=notes, fictional=fictional,
+                                    element=element, othername=othername,
+                                    modelname=modelname, year=year,
+                                    author=author, abstract=abstract)
         return mquery
 
-    @staticmethod
-    def cdcsquery(key=None, id=None, notes=None,
+    def cdcsquery(self, key=None, id=None, notes=None,
                   fictional=None, element=None, othername=None, modelname=None,
                   year=None, author=None, abstract=None):
-        mquery = {}
-        root = modelroot
-        query.str_match.mongo(mquery, f'{root}.key', key)
-        query.str_match.mongo(mquery, f'{root}.id', id)
-        query.str_contains.mongo(mquery, f'{root}.notes', notes)
+        """
+        Builds a CDCS-style query based on kwargs values for the record style.
         
-        query.int_match.mongo(mquery, f'{root}.description.citation.publication-date.year', year)
-        query.str_contains.mongo(mquery, f'{root}.description.citation.author.surname', author)
-        query.str_contains.mongo(mquery, f'{root}.description.citation.abstract', abstract)
+        Parameters
+        ----------
+        key : str or list
+            The unique potential id(s) to parse by.
+        id : str or list
+            The UUID4 potential key(s) to parse by.
+        notes : str or list
+            Terms in the notes to parse for.
+        fictional : bool or list
+            Value of fictional to parse for.
+        element : str or list
+            Element(s) to parse by.
+        othername : str or list
+            Other name(s) to parse by.
+        modelname : str or list
+            Model name(s) to parse by.
+        year : int or list
+            Publication/creation year(s) to parse by.
+        author : str or list
+            Author(s) to parse by.  Only last names guaranteed to work.
+        abstract : str or list
+            Terms in the publication abstracts to parse for.
+        
+        Returns
+        -------
+        dict
+            The CDCS-style query
+        """
+        
+        mquery = super().cdcsquery(key=key, id=id,
+                                   notes=notes, fictional=fictional,
+                                   element=element, othername=othername,
+                                   modelname=modelname, year=year,
+                                   author=author, abstract=abstract)
         return mquery
